#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-floskell-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-floskell-plugin-2.3.0.0-J2fR8OdKRUSDJdUUtdINmn
key:                  hls-floskell-plugin-2.3.0.0-J2fR8OdKRUSDJdUUtdINmn
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Floskell code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  2cc8db1cae1bc22e5c64995ec9f8a022
exposed:              True
exposed-modules:      Ide.Plugin.Floskell
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-floskell-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-floskell-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-floskell-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-floskell-plugin
hs-libraries:         HShls-floskell-plugin-2.3.0.0-J2fR8OdKRUSDJdUUtdINmn
depends:
    base-4.18.2.1 floskell-0.10.8-4KZdM9WVcM32LLQDqWFCjT
    ghcide-2.3.0.0-6w7l3MFr3s5GGmPeFyak7n
    hls-plugin-api-2.3.0.0-LfFc7Z03YyoGYY0VVD4QTJ
    lsp-types-2.0.2.0-xmc6WCw8XEoIKXtrPVFU mtl-2.3.1 text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-hls-floskell-plugin/html/hls-floskell-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-floskell-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

